==> haskell-aeson-diff-1.1.0.9-186-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-diff
version:              1.1.0.9
visibility:           public
id:                   aeson-diff-1.1.0.9-97Tjc9mMHLj7uTgMsqDrc1
key:                  aeson-diff-1.1.0.9-97Tjc9mMHLj7uTgMsqDrc1
license:              BSD-3-Clause
copyright:            (c) 2015 Thomas Sutton and others.
maintainer:           me@thomas-sutton.id.au
author:               Thomas Sutton
homepage:             https://github.com/thsutton/aeson-diff
synopsis:             Extract and apply patches to JSON documents.
description:

    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.

category:             JSON, Web, Algorithms
abi:                  ca8da99954d5231972fef8a046b863f6
exposed:              True
exposed-modules:      Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs:          /usr/lib/ghc-8.10.4/site-local/aeson-diff-1.1.0.9
library-dirs:         /usr/lib/ghc-8.10.4/site-local/aeson-diff-1.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/aeson-diff-1.1.0.9
hs-libraries:         HSaeson-diff-1.1.0.9-97Tjc9mMHLj7uTgMsqDrc1
depends:
    aeson-1.5.6.0-Er8hVcKeB6UIjaphu3gpm9 base-4.14.1.0
    bytestring-0.10.12.0
    edit-distance-vector-1.0.0.4-19T3k8VA4qk5ExatdKNLrY
    hashable-1.3.1.0-4EsGp1K7uOu2cACWuCidz3 mtl-2.2.2
    scientific-0.3.6.2-ErrVUcpZzeLEYjP4jqSF4S text-1.2.4.1
    unordered-containers-0.2.13.0-4AoMTstniRpGNa4LW5BINH
    vector-0.12.3.0-H4rWOat9KWYJKIFglDYjhy

haddock-interfaces:   /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html:         /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-diff-1.1.0.9-189-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-diff
version:              1.1.0.9
visibility:           public
id:                   aeson-diff-1.1.0.9-B4ka0vye9B0LVyCVQ478dp
key:                  aeson-diff-1.1.0.9-B4ka0vye9B0LVyCVQ478dp
license:              BSD-3-Clause
copyright:            (c) 2015 Thomas Sutton and others.
maintainer:           me@thomas-sutton.id.au
author:               Thomas Sutton
homepage:             https://github.com/thsutton/aeson-diff
synopsis:             Extract and apply patches to JSON documents.
description:

    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.

category:             JSON, Web, Algorithms
abi:                  8fbce54bfc250c6d64539833945cbe9b
exposed:              True
exposed-modules:      Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs:          /usr/lib/ghc-8.10.4/site-local/aeson-diff-1.1.0.9
library-dirs:         /usr/lib/ghc-8.10.4/site-local/aeson-diff-1.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/aeson-diff-1.1.0.9
hs-libraries:         HSaeson-diff-1.1.0.9-B4ka0vye9B0LVyCVQ478dp
depends:
    aeson-1.5.6.0-4lI4Q9XYYOw6EMYr9f1A41 base-4.14.1.0
    bytestring-0.10.12.0
    edit-distance-vector-1.0.0.4-1tiDofGZS5k8spLuaoekbL
    hashable-1.3.2.0-5x51STP8vZMKBx9J0CoY3R mtl-2.2.2
    scientific-0.3.6.2-634NpkEKV4MKLZFZCJgk18 text-1.2.4.1
    unordered-containers-0.2.13.0-KzaktTJkN1lG5bdgci6oxQ
    vector-0.12.3.0-HURuJbi2iJT3pZcjBMuHYu

haddock-interfaces:   /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html:         /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
